@@ -34,11 +34,15 @@ from urllib.request import urlretrieve
 
 notebooks_url = 'https://github.com/theislab/scarches/raw/master/notebooks/'
 notebooks = [
-    'zenodo_pancreas_from_pretrained.ipynb',
-    'zenodo_pancreas_from_scratch.ipynb',
-    'pancreas_pipeline.ipynb',
-    'zenodo_intestine.ipynb'
-
+    'scanvi_surgery_pipeline.ipynb',
+    'scvi_surgery_pipeline.ipynb',
+    'totalvi_surgery_pipeline.ipynb',
+    'trvae_surgery_pipeline.ipynb',
+    'trVAE_zenodo_pipeline.ipynb',
+    'reference_building_from_scratch.ipynb',
+    'scgen_map_query.ipynb',
+    'expimap_surgery_pipeline_basic.ipynb',
+    'expimap_surgery_pipeline_advanced.ipynb'
 ]
 
 for nb in notebooks:
@@ -50,11 +54,9 @@ for nb in notebooks:
 # -- Project information -----------------------------------------------------
 
 project = 'scArches'
-copyright = f'{datetime.now():%Y}, Mohsen Naghipourfar, Mohammad Lotfollahi'
-author = 'Mohsen Naghipourfar, Mohammad Lotfollahi'
+author = 'Marco Wagenstetter, Mohammad Lotfollahi, Mohsen Naghipourfar, Sergei Rybakov'
+copyright = f'{datetime.now():%Y}, ' + author
 
-# version = scarches.__version__
-# release = version
 pygments_style = 'sphinx'
 todo_include_todos = True
 html_theme_options = dict(navigation_depth=3, titles_only=False)
@@ -69,8 +71,7 @@ html_static_path = ['_static']
 
 
 def setup(app):
-    app.add_stylesheet('custom.css')
-
+    app.add_css_file('custom.css')
 
 # -- General configuration ---------------------------------------------------
 
@@ -108,7 +109,7 @@ templates_path = ['_templates']
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store', '**.ipynb_checkpoints']
 
 
 def linkcode_resolve(domain, info):
